/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.taglib.html;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.taglib.TagUtils;
import org.apache.struts.taglib.html.LinkTag;
import org.hdiv.dataComposer.IDataComposer;
import org.hdiv.taglib.util.RequestUtilsHDIV;
import org.hdiv.util.HDIVUtil;

/**
 * Generate a URL-encoded hyperlink to the specified URI.
 * 
 * @author Gorka Vicente
 * @see org.apache.struts.taglib.html.LinkTag
 */
public class LinkTagHDIV extends LinkTag {

	/**
	 * Universal version identifier. Deserialization uses this number to ensure that
	 * a loaded class corresponds exactly to a serialized object.
	 */
	private static final long serialVersionUID = -376718532211972980L;

	/**
	 * Commons logging instance
	 */
	private static final Log log = LogFactory.getLog(LinkTagHDIV.class);

	private IDataComposer dataComposer;


	/**
	 * Render the beginning of the hyperlink.
	 * <p>
	 * Support for indexed property since Struts 1.1.
	 * </p>
	 * 
	 * @exception JspException if a JSP exception has occurred
	 * @see org.hdiv.taglib.util.RequestUtilsHDIV
	 * @version This version is only for Struts 1.1
	 */
	public int doStartTag() throws JspException {

        HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();        
		dataComposer = HDIVUtil.getDataComposer();

		// Validate if any specifier was included
		if ((forward == null) && (href == null) && (page == null) && (action == null)) {
			return super.doStartTag();
		}

		// the value specified in linkname will render a "name" element in the
		// generated anchor tag
		if (this.getLinkName() != null) {
			return super.doStartTag();
		}

		// return the complete URL to which this hyperlink will direct the user.
		String url = calculateURL();

		String urlWithoutRelativePaths = RequestUtilsHDIV.getURLWithoutRelativePaths(request, url);

		if (urlWithoutRelativePaths == null) {
			if (log.isDebugEnabled()) {
				log.debug("Action " + url + " don't go to our application. URL:" + url);
			}
			return super.doStartTag();
		}

		// Generate the opening anchor element
		StringBuffer results = new StringBuffer("<a");

		// If useLocalEncoding set to true, urlencoding is done on the bytes of
		// character encoding from ServletResponse#getCharacterEncoding. Use UTF-8
		// otherwise.
		String charEncoding = "UTF-8";
	    if (useLocalEncoding){
	    	charEncoding = pageContext.getResponse().getCharacterEncoding();
	    }
		String encodedURL = RequestUtilsHDIV.encodeValues(url, urlWithoutRelativePaths, charEncoding);

		String urlWithHDIVParameter = RequestUtilsHDIV.addHDIVState(encodedURL, this.getAnchor());		

		renderAttribute(results, "href", urlWithHDIVParameter);
		renderAttribute(results, "target", getTarget());
		renderAttribute(results, "accesskey", getAccesskey());
		renderAttribute(results, "tabindex", getTabindex());

		results.append(prepareStyles());
		results.append(prepareEventHandlers());
		prepareOtherAttributes(results);
		results.append(">");

		TagUtils.getInstance().write(pageContext, results.toString());

		// Evaluate the body of this tag
		this.text = null;
		return (EVAL_BODY_TAG);
	}

	/**
	 * Prepares an attribute if the <code>value</code> is not null, appending it to
	 * the the given StringBuffer <code>result</code>.
	 * 
	 * @param result The StringBuffer that output will be appended to.
	 */
	private void renderAttribute(StringBuffer result, String name, String value) {

		if (value != null) {
			result.append(" ");
			result.append(name);
			result.append("=\"");
			result.append(value);
			result.append("\"");
		}
	}

	/**
	 * 'Hook' to enable tags to be extended and additional attributes added.
	 * 
	 * @param handlers The StringBuffer that output will be appended to.
	 */
	protected void prepareOtherAttributes(StringBuffer handlers) {

	}

}
