/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.taglib.html;

import java.util.HashMap;
import java.util.Locale;

import javax.servlet.jsp.PageContext;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.cactus.JspTestCase;
import org.apache.struts.Globals;
import org.apache.struts.taglib.html.Constants;
import org.hdiv.taglib.SimpleBeanForTesting;

/**
 * Suite of unit tests for the <code>org.hdiv.taglib.html.LinkTagHDIV</code> class.
 */
public class LinkTag9Test extends JspTestCase {

	/**
	 * Defines the testcase name for JUnit.
	 * 
	 * @param theName the testcase's name.
	 */
	public LinkTag9Test(String theName) {
		super(theName);
	}

	/**
	 * Start the tests.
	 * 
	 * @param theArgs the arguments. Not used
	 */
	public static void main(String[] theArgs) {
		junit.awtui.TestRunner.main(new String[] { LinkTag9Test.class.getName() });
	}

	/**
	 * @return a test suite (<code>TestSuite</code>) that includes all methods
	 *         starting with "test"
	 */
	public static Test suite() {
		// All methods starting with "test" will be executed in the test suite.
		return new TestSuite(LinkTag9Test.class);
	}

	private void runMyTest(String whichTest, String locale) {

		pageContext.setAttribute(Globals.LOCALE_KEY, new Locale(locale, locale),
									PageContext.SESSION_SCOPE);
		pageContext.setAttribute(Constants.BEAN_KEY, new SimpleBeanForTesting("Test Value"),
									PageContext.REQUEST_SCOPE);
		request.setAttribute("runTest", whichTest);
		try {
			pageContext.forward("/test/org/hdiv/taglib/html/TestLinkTag9.jsp");
		} catch (Exception e) {
			e.printStackTrace();
			fail("There is a problem that is preventing the tests to continue!");
		}
	}

	/*
	 * Testing LinkTagHDIV.
	 */

	public void testLinkUsingPageAttribute() {
		runMyTest("testLinkUsingPageAttribute", "");
	}

	public void testLinkUsingActionAttribute() {
		runMyTest("testLinkUsingActionAttribute", "");
	}

	public void testLinkToAnAnchor() {
		runMyTest("testLinkToAnAnchor", "");
	}

	public void testLinkHardcodedParameter() {
		runMyTest("testLinkHardcodedParameter", "");
	}

	public void testLinkDynamicParameter() {
		pageContext.setAttribute("myColor", "paramValue", PageContext.REQUEST_SCOPE);
		runMyTest("testLinkDynamicParameter", "");
	}

	public void testLinkDynamicParameterFromBeanProperty() {
		SimpleBeanForTesting sbft = new SimpleBeanForTesting("paramPropertyValue");
		pageContext.setAttribute("data", sbft, PageContext.REQUEST_SCOPE);
		runMyTest("testLinkDynamicParameterFromBeanProperty", "");
	}

	public void testLinkMultipleDynamicParametersFromMap() {
		HashMap map = new HashMap();
		map.put("color", "Red");
		map.put("fruit", "Apple");
		map.put("animal", "Rabbit");
		pageContext.setAttribute("paramMap", map, PageContext.REQUEST_SCOPE);
		runMyTest("testLinkMultipleDynamicParametersFromMap", "");
	}

	public void testLinkWithAnormalCharacters() {
		runMyTest("testLinkWithAnormalCharacters", "");
	}

}
